@@ -1,14 +1,18 @@
 from pydantic import BaseModel
-from typing import Optional
+from typing import Optional, List
 
 
 class DepartmentsParams(BaseModel):
     nom: Optional[str]
+    codeRegion: Optional[str]
+    code: Optional[str]
     limit: Optional[int]
+    fields: Optional[List[str]]
 
 
 class DepartmentCodeParams(BaseModel):
     code: Optional[str]
+    fields: Optional[list]
     limit: Optional[int]
 
 
@@ -22,4 +26,5 @@ class DepartmentsResponse(BaseModel):
     nom: str
     code: int
     codeRegion: int
+    fields: Optional[list]
     _score: Optional[float]
